Card

Struct Card 

pub struct Card(/* private fields */);
A Card is a Newtype u32 representation of a variant of Cactus Kev’s binary representation of a poker card as designed for rapid hand evaluation as documented here.

The variation being that the Suit bits order is inverted for easier sorting.

+--------+--------+--------+--------+
|mmmbbbbb|bbbbbbbb|SHDCrrrr|xxpppppp|
+--------+--------+--------+--------+

p = prime number of rank (deuce=2,trey=3,four=5,...,ace=41)
r = rank of card (deuce=0,trey=1,four=2,five=3,...,ace=12)
SHDC = suit of card (bit turned on based on suit of card)
b = bit turned on depending on rank of card
m = Flags reserved for multiples of the same rank. Stripped for evals.

Implementations

Source

impl Card

pub const RANK_FLAG_FILTER: u32 = 0x1FFF_0000

pub const RANK_FLAG_SHIFT: u32 = 16

pub const RANK_PRIME_FILTER: u32 = 0b0011_1111

pub const SUIT_FLAG_FILTER: u32 = 0xF000

Binary filter for CardNumber Suit flags. 00000000 00000000 11110000 00000000

pub const SUIT_SHORT_MASK: u32 = 0b1111

pub const SUIT_FLAG_SHIFT: u32 = 12

pub const FREQUENCY_PAIRED_MASK: u32 = 0b0010_0000_0000_0000_0000_0000_0000_0000

Frequency Weight masks

pub const FREQUENCY_TRIPPED_MASK: u32 = 0b0100_0000_0000_0000_0000_0000_0000_0000

pub const FREQUENCY_QUADED_MASK: u32 = 0b1000_0000_0000_0000_0000_0000_0000_0000

pub const FREQUENCY_MASK: u32 = 0b1110_0000_0000_0000_0000_0000_0000_0000

pub const FREQUENCY_MASK_FILTER: u32 = 0b0001_1111_1111_1111_1111_1111_1111_1111

pub const ACE_SPADES: Card

pub const KING_SPADES: Card

pub const QUEEN_SPADES: Card

pub const JACK_SPADES: Card

pub const TEN_SPADES: Card

pub const NINE_SPADES: Card

pub const EIGHT_SPADES: Card

pub const SEVEN_SPADES: Card

pub const SIX_SPADES: Card

pub const FIVE_SPADES: Card

pub const FOUR_SPADES: Card

pub const TREY_SPADES: Card

pub const DEUCE_SPADES: Card

pub const ACE_HEARTS: Card

pub const KING_HEARTS: Card

pub const QUEEN_HEARTS: Card

pub const JACK_HEARTS: Card

pub const TEN_HEARTS: Card

pub const NINE_HEARTS: Card

pub const EIGHT_HEARTS: Card

pub const SEVEN_HEARTS: Card

pub const SIX_HEARTS: Card

pub const FIVE_HEARTS: Card

pub const FOUR_HEARTS: Card

pub const TREY_HEARTS: Card

pub const DEUCE_HEARTS: Card

pub const ACE_DIAMONDS: Card

pub const KING_DIAMONDS: Card

pub const QUEEN_DIAMONDS: Card

pub const JACK_DIAMONDS: Card

pub const TEN_DIAMONDS: Card

pub const NINE_DIAMONDS: Card

pub const EIGHT_DIAMONDS: Card

pub const SEVEN_DIAMONDS: Card

pub const SIX_DIAMONDS: Card

pub const FIVE_DIAMONDS: Card

pub const FOUR_DIAMONDS: Card

pub const TREY_DIAMONDS: Card

pub const DEUCE_DIAMONDS: Card

pub const ACE_CLUBS: Card

pub const KING_CLUBS: Card

pub const QUEEN_CLUBS: Card

pub const JACK_CLUBS: Card

pub const TEN_CLUBS: Card

pub const NINE_CLUBS: Card

pub const EIGHT_CLUBS: Card

pub const SEVEN_CLUBS: Card

pub const SIX_CLUBS: Card

pub const FIVE_CLUBS: Card

pub const FOUR_CLUBS: Card

pub const TREY_CLUBS: Card

pub const DEUCE_CLUBS: Card

pub const BLANK: Card

pub fn new(rank: Rank, suit: Suit) -> Self

pub fn filter(card: Card) -> Result<Self, PKError>

Errors

Returns PKError::BlankCard if the Card is blank.

pub fn as_u32(&self) -> u32

Returns the Cactus Kev Card u32 number of the Card.

pub fn bit_string(&self) -> String

pub fn bit_string_guided(&self) -> String

This code is doing too much. I need to Uncle Bob it. Aside on why I am giving up that phrase.

pub fn frequency_paired(&self) -> Card

Returns a new version of Card with the paired frequency bit set.

pub fn frequency_tripped(&self) -> Card

Returns a new version of Card with the tripped frequency bit set.

pub fn frequency_quaded(&self) -> Card

Returns a new version of Card with the quaded frequency bit set.

Quaded??!!

pub fn get_letter_index(&self) -> String

pub fn get_rank(&self) -> Rank

pub fn get_rank_prime(&self) -> u32

pub fn get_suit(&self) -> Suit

pub fn is_flagged(&self, flag: u32) -> bool